@@ -54,6 +54,7 @@ namespace torali
     uint16_t minTraQual;
     uint16_t minGenoQual;
     uint16_t madCutoff;
+    uint16_t madNormalCutoff;
     int32_t nchr;
     int32_t minimumFlankSize;
     int32_t indelsize;
@@ -61,6 +62,8 @@ namespace torali
     uint32_t minRefSep;
     uint32_t maxReadSep;
     uint32_t minClip;
+    uint32_t maxGenoReadCount;
+    uint32_t minCliqueSize;
     float flankQuality;
     bool hasExcludeFile;
     bool hasVcfFile;
@@ -196,6 +199,7 @@ namespace torali
   int delly(int argc, char **argv) {
     Config c;
     c.isHaplotagged = false;
+    c.madNormalCutoff = 5;
 
     // Define generic options
     std::string svtype;
@@ -214,6 +218,7 @@ namespace torali
       ("qual-tra,r", boost::program_options::value<uint16_t>(&c.minTraQual)->default_value(20), "min. PE quality for translocation")
       ("mad-cutoff,s", boost::program_options::value<uint16_t>(&c.madCutoff)->default_value(9), "insert size cutoff, median+s*MAD (deletions only)")
       ("minclip,c", boost::program_options::value<uint32_t>(&c.minClip)->default_value(25), "min. clipping length")
+      ("min-clique-size,z", boost::program_options::value<uint32_t>(&c.minCliqueSize)->default_value(2), "min. PE/SR clique size")
       ("minrefsep,m", boost::program_options::value<uint32_t>(&c.minRefSep)->default_value(25), "min. reference separation")
       ("maxreadsep,n", boost::program_options::value<uint32_t>(&c.maxReadSep)->default_value(40), "max. read separation")
       ;
@@ -230,6 +235,7 @@ namespace torali
     hidden.add_options()
       ("input-file", boost::program_options::value< std::vector<boost::filesystem::path> >(&c.files), "input file")
       ("pruning,j", boost::program_options::value<uint32_t>(&c.graphPruning)->default_value(1000), "PE graph pruning cutoff")
+      ("max-geno-count,a", boost::program_options::value<uint32_t>(&c.maxGenoReadCount)->default_value(250), "max. number of reads aligned for SR genotyping")
       ;
     
     boost::program_options::positional_options_description pos_args;
@@ -259,6 +265,9 @@ namespace torali
     // Dump PE and SR support?
     if (vm.count("dump")) c.hasDumpFile = true;
     else c.hasDumpFile = false;
+
+    // Clique size
+    if (c.minCliqueSize < 2) c.minCliqueSize = 2;
     
     // Check quality cuts
     if (c.minMapQual > c.minTraQual) c.minTraQual = c.minMapQual;
